@@ -3,6 +3,6 @@
 #' @keywords internal
 #' @note see `crminer::crm_links`
 #' @rdname cr_ft_links-defunct
-cr_ft_links <- function(...) {
+cr_ft_links <- function(...) { # nocov start
   .Defunct(package = "crminer", msg = "Removed - see crminer::crm_links()")
-}
+} # nocov end
