@@ -3,9 +3,9 @@
 #' @export
 #' @rdname crosscite-defunct
 #' @keywords internal
-`crosscite` <- function(...) {
+`crosscite` <- function(...) { # nocov start
   .Defunct(
     package = "rcrossref", 
     msg = "Removed - see cr_works(), cr_journals(), etc. for similar functionality"
   )
-}
+} # nocov end
